@@ -10,29 +10,29 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.4.21-58.EL.src.rpm ]
+if [ ! -r kernel-2.4.21-63.EL.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/centos/3.9/updates/SRPMS/kernel-2.4.21-58.EL.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/centos/3.9/updates/SRPMS/kernel-2.4.21-63.EL.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.4.21-58.EL.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.4.21-63.EL.src.rpm || die "Can't install source package."
 
 cd /usr/src/redhat/SOURCES/ || die "Can't chdir to /usr/src/redhat/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.8-20090528.tar.gz ]
+if [ ! -r ccs-patch-1.6.8-20100120.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20090528.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20100120.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/redhat/SPECS/kernel-2.4.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-2.4.spec	2008-05-07 18:06:28.000000000 +0900
-+++ kernel-2.4.spec	2008-12-10 10:45:59.000000000 +0900
+--- kernel-2.4.spec	2009-11-04 07:31:03.000000000 +0900
++++ kernel-2.4.spec	2009-11-04 16:48:08.000000000 +0900
 @@ -20,7 +20,7 @@
  # that the kernel isn't the stock RHL kernel, for example by
  # adding some text to the end of the version number.
  #
--%define release 58.EL
-+%define release 58.EL_tomoyo_1.6.8
+-%define release 63.EL
++%define release 63.EL_tomoyo_1.6.8p3
  %define sublevel 21
  %define kversion 2.4.%{sublevel}
  # /usr/src/%{kslnk} -> /usr/src/linux-%{KVERREL}
@@ -45,18 +45,18 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{kversion}
-@@ -1890,6 +1890,10 @@
+@@ -1921,6 +1921,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.8-20090528.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.6.8-20100120.tar.gz
 +patch -sp1 < patches/ccs-patch-2.4.21-centos-3.9.diff
 +
  cp %{SOURCE10} Documentation/
  
  mkdir configs
-@@ -1945,6 +1949,8 @@
+@@ -1976,6 +1980,8 @@
  # since make mrproper wants to wipe out .config files, we move our mrproper
  # up before we copy the config files around.
      cp configs/kernel-%{kversion}-$Config.config .config
