@@ -17,9 +17,9 @@ fi
 rpm -ivh kernel-2.4.20-46.9.legacy.src.rpm || die "Can't install source package."
 
 cd /usr/src/redhat/SOURCES/ || die "Can't chdir to /usr/src/redhat/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.3-20080715.tar.gz ]
+if [ ! -r ccs-patch-1.6.8-20100120.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.3-20080715.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20100120.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -32,7 +32,7 @@ patch << "EOF" || die "Can't patch spec file."
  # adding some text to the end of the version number.
  #
 -%define release 46.9.legacy
-+%define release 46.9.legacy_tomoyo_1.6.3
++%define release 46.9.legacy_tomoyo_1.6.8p3
  %define sublevel 20
  %define kversion 2.4.%{sublevel}
  # /usr/src/%{kslnk} -> /usr/src/linux-%{KVERREL}
@@ -50,9 +50,9 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.3-20080715.tar.gz
-+sed -i -e "s/^SUBLEVEL.*/SUBLEVEL = 20/" -e "s/^EXTRAVERSION.*/EXTRAVERSION = -46.9.legacycustom/" -- Makefile
-+patch -sp1 < patches/ccs-patch-2.4.20-46.9.legacy.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.8-20100120.tar.gz
++# sed -i -e "s/^SUBLEVEL.*/SUBLEVEL = 20/" -e "s/^EXTRAVERSION.*/EXTRAVERSION = -46.9.legacycustom/" -- Makefile
++patch -sp1 < patches/ccs-patch-2.4.20-redhat-linux-9.diff
 +
  cp %{SOURCE10} Documentation/
  chmod +x arch/sparc*/kernel/check_asm.sh
@@ -67,11 +67,11 @@ patch << "EOF" || die "Can't patch spec file."
      perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$2/" Makefile
  %ifarch sparc sparc64     
 EOF
-mv kernel-2.4.spec kernel-2.4.20-46.9.legacy_tomoyo_1.6.3.spec || die "Can't rename spec file."
+mv kernel-2.4.spec ccs-kernel.spec || die "Can't rename spec file."
 echo ""
 echo ""
 echo ""
-echo "Edit /tmp/kernel-2.4.20-46.9.legacy_tomoyo_1.6.3.spec if needed, and run"
-echo "rpmbuild -bb /tmp/kernel-2.4.20-46.9.legacy_tomoyo_1.6.3.spec"
+echo "Edit /tmp/ccs-kernel.spec if needed, and run"
+echo "rpmbuild -bb /tmp/ccs-kernel.spec"
 echo "to build kernel rpm packages."
 exit 0
