@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for openSUSE 11.1's 2.6.27 kernel.
+# This is a kernel build script for openSUSE 11.0's 2.6.25 kernel.
 #
 
 die () {
@@ -60,41 +60,37 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-2.6.27.21-0.1.1.src.rpm ]
+if [ ! -r kernel-source-2.6.25.20-0.5.src.rpm ]
 then
-    wget http://download.opensuse.org/source/distribution/11.1/repo/oss/suse/src/kernel-source-2.6.27.21-0.1.1.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.0/rpm/src/kernel-source-2.6.25.20-0.5.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-source-2.6.27.21-0.1.1.src.rpm || die "Can't install source package."
+rpm -ivh kernel-source-2.6.25.20-0.5.src.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.8-20090528.tar.gz ]
+if [ ! -r ccs-patch-1.6.8-20100120.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20090528.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20100120.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/packages/SOURCES/kernel-default.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-default.spec	2009-04-02 01:23:52.000000000 +0900
-+++ kernel-default.spec	2009-04-08 20:03:03.000000000 +0900
-@@ -57,13 +57,13 @@
- %if %build_vanilla || %build_kdump || %CONFIG_MODULES != "y"
- %define split_packages 0
- %else
--%define split_packages 1
-+%define split_packages 0
+--- kernel-default.spec	2009-06-02 08:59:34.000000000 +0900
++++ kernel-default.spec	2009-06-09 12:06:33.000000000 +0900
+@@ -47,10 +47,10 @@
+ %define build_nomodules 1
  %endif
  
 -Name:           kernel-default
 +Name:           ccs-kernel-default
- Summary:        The Standard Kernel
- Version:        2.6.27.21
--Release:        0.<RELEASE1>
-+Release:        0.1.1_tomoyo_1.6.8
- License:        GPL v2 only
+ Summary:        The Standard Kernel for both Uniprocessor and Multiprocessor Systems
+ Version:        2.6.25.20
+-Release: 0.5
++Release: 0.5_tomoyo_1.6.8p3
+ License:        GPL v2 or later
  Group:          System/Kernel
  Url:            http://www.kernel.org/
-@@ -223,7 +223,7 @@
+@@ -213,7 +213,7 @@
  %define tolerate_unknown_new_config_options 0
  # kABI change tolerance (default in maintenance should be 4, 6, 8 or 15,
  # 31 is the maximum; see scripts/kabi-checks)
@@ -103,19 +99,19 @@ patch << "EOF" || die "Can't patch spec file."
  
  %description
  The standard kernel for both uniprocessor and multiprocessor systems.
-@@ -308,6 +308,10 @@
+@@ -315,6 +315,10 @@
  %build
  source .rpm-defs
- cd linux-2.6.27
+ cd linux-2.6.25
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.8-20090528.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.27-suse-11.1.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.8-20100120.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.25-suse-11.0.diff
 +cat config.ccs >> .config
  cp .config .config.orig
  %if %{tolerate_unknown_new_config_options}
  MAKE_ARGS="$MAKE_ARGS -k"
 EOF
-sed -e 's:^Provides:#Provides:' -e 's:^Obsoletes:#Obsoletes:' -e 's:-n kernel:-n ccs-kernel:' kernel-default.spec > ccs-kernel.spec || die "Can't edit spec file."
+sed -e 's:^Provides:#Provides:' -e 's:^Obsoletes:#Obsoletes:' kernel-default.spec > ccs-kernel.spec || die "Can't edit spec file."
 echo ""
 echo ""
 echo ""
