@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for VineLinux 4.2's 2.6.16 kernel.
+# This is a kernel build script for VineLinux 5.0's 2.6.27 kernel.
 #
 
 die () {
@@ -10,33 +10,33 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.16-76.49vl4.src.rpm ]
+if [ ! -r kernel-2.6.27-46vl5.src.rpm ]
 then
-    wget http://updates.vinelinux.org/Vine-4.2/updates/SRPMS/kernel-2.6.16-76.49vl4.src.rpm || die "Can't download source package."
+    wget http://updates.vinelinux.org/Vine-5.0/updates/SRPMS/kernel-2.6.27-46vl5.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.16-76.49vl4.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.27-46vl5.src.rpm || die "Can't install source package."
 
 cd /usr/src/vine/SOURCES/ || die "Can't chdir to /usr/src/vine/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.8-20090528.tar.gz ]
+if [ ! -r ccs-patch-1.6.8-20100120.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20090528.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20100120.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/vine/SPECS/kernel-2.6-vl.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-2.6-vl.spec	2009-05-12 20:38:04.000000000 +0900
-+++ kernel-2.6-vl.spec	2009-05-26 10:25:43.000000000 +0900
-@@ -23,7 +23,7 @@
- %define sublevel 16
+--- kernel-2.6-vl.spec	2009-10-07 08:47:44.000000000 +0900
++++ kernel-2.6-vl.spec	2009-10-29 00:08:25.000000000 +0900
+@@ -27,7 +27,7 @@
+ %define patchlevel 36
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
--%define release 76.49%{_dist_release}
-+%define release 76.49%{_dist_release}_tomoyo_1.6.8
+-%define release 46%{?_dist_release}
++%define release 46%{?_dist_release}_tomoyo_1.6.8p3
  
  %define make_target bzImage
- 
-@@ -100,6 +100,9 @@
+ %define hdrarch %_target_cpu
+@@ -121,6 +121,9 @@
  # to versions below the minimum
  #
  
@@ -46,27 +46,27 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -126,7 +129,7 @@
+@@ -153,7 +156,7 @@
  #
- %define kernel_prereq  fileutils, modutils >= 3.2.2 , initscripts >= 5.83, mkinitrd >= 4.2.1.8-0vl2.1
+ %define kernel_prereq  fileutils, module-init-tools >= 3.6, initscripts >= 8.80, mkinitrd >= 5.1.19.6, kernel-firmware >= %{version}
  
 -Name: kernel
 +Name: ccs-kernel
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -1139,6 +1142,10 @@
+@@ -763,6 +766,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.8-20090528.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.16-vine-linux-4.2.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.8-20100120.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.27-vine-linux-5.0.diff
 +
  cp %{SOURCE10} Documentation/
  
  # put Vine logo
-@@ -1159,6 +1166,9 @@
+@@ -781,6 +788,9 @@
  for i in *.config
  do 
  	mv $i .config 
