@@ -3,9 +3,9 @@
  *
  * Implementation of the Domain-Based Mandatory Access Control.
  *
- * Copyright (C) 2005-2008  NTT DATA CORPORATION
+ * Copyright (C) 2005-2009  NTT DATA CORPORATION
  *
- * Version: 1.6.4   2008/09/03
+ * Version: 1.6.8   2009/05/28
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -16,31 +16,31 @@
 #include <linux/tomoyo.h>
 #include <linux/realpath.h>
 #include <linux/highmem.h>
-#include <linux/binfmts.h>
 
 /**
  * ccs_print_bprm - Print "struct linux_binprm" for auditing.
  *
  * @bprm: Pointer to "struct linux_binprm".
+ * @dump: Pointer to "struct ccs_page_dump".
  *
  * Returns the contents of @bprm on success, NULL otherwise.
  */
-static char *ccs_print_bprm(struct linux_binprm *bprm)
+static char *ccs_print_bprm(struct linux_binprm *bprm,
+			    struct ccs_page_dump *dump)
 {
-	static const int buffer_len = 4096 * 2;
-	char *buffer = ccs_alloc(buffer_len);
+	static const int ccs_buffer_len = 4096 * 2;
+	char *buffer = ccs_alloc(ccs_buffer_len, false);
 	char *cp;
 	char *last_start;
 	int len;
 	unsigned long pos = bprm->p;
-	int i = pos / PAGE_SIZE;
 	int offset = pos % PAGE_SIZE;
 	int argv_count = bprm->argc;
 	int envp_count = bprm->envc;
 	bool truncated = false;
 	if (!buffer)
 		return NULL;
-	len = snprintf(buffer, buffer_len - 1,
+	len = snprintf(buffer, ccs_buffer_len - 1,
 		       "argc=%d envc=%d argv[]={ ", argv_count, envp_count);
 	cp = buffer + len;
 	if (!argv_count) {
@@ -49,30 +49,16 @@ static char *ccs_print_bprm(struct linux_binprm *bprm)
 	}
 	last_start = cp;
 	while (argv_count || envp_count) {
-		struct page *page;
-		const char *kaddr;
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 23) && defined(CONFIG_MMU)
-		if (get_user_pages(current, bprm->mm, pos, 1, 0, 1, &page,
-				   NULL) <= 0)
+		if (!ccs_dump_page(bprm, pos, dump))
 			goto out;
 		pos += PAGE_SIZE - offset;
-#else
-		page = bprm->page[i];
-#endif
-		/* Map */
-		kaddr = kmap(page);
-		if (!kaddr) { /* Mapping failed. */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 23) && defined(CONFIG_MMU)
-			put_page(page);
-#endif
-			goto out;
-		}
 		/* Read. */
 		while (offset < PAGE_SIZE) {
+			const char *kaddr = dump->data;
 			const unsigned char c = kaddr[offset++];
 			if (cp == last_start)
 				*cp++ = '"';
-			if (cp >= buffer + buffer_len - 32) {
+			if (cp >= buffer + ccs_buffer_len - 32) {
 				/* Reserve some room for "..." string. */
 				truncated = true;
 			} else if (c == '\\') {
@@ -116,177 +102,229 @@ static char *ccs_print_bprm(struct linux_binprm *bprm)
 			if (!argv_count && !envp_count)
 				break;
 		}
-		/* Unmap. */
-		kunmap(page);
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 23) && defined(CONFIG_MMU)
-		put_page(page);
-#endif
-		i++;
 		offset = 0;
 	}
 	*cp++ = '}';
 	*cp = '\0';
 	return buffer;
  out:
-	snprintf(buffer, buffer_len - 1,
+	snprintf(buffer, ccs_buffer_len - 1,
 		 "argc=%d envc=%d argv[]={ ... } envp[]= { ... }",
 		 argv_count, envp_count);
 	return buffer;
 }
 
-static DECLARE_WAIT_QUEUE_HEAD(grant_log_wait);
-static DECLARE_WAIT_QUEUE_HEAD(reject_log_wait);
-
-static DEFINE_SPINLOCK(audit_log_lock);
-
-/* Structure for audit log. */
-struct log_entry {
-	struct list_head list;
-	char *log;
-};
-
-/* The list for "struct log_entry". */
-static LIST_HEAD(grant_log);
-
-/* The list for "struct log_entry". */
-static LIST_HEAD(reject_log);
-
-static int grant_log_count;
-static int reject_log_count;
-
 /**
  * ccs_init_audit_log - Allocate buffer for audit logs.
  *
- * @len:     Required size.
- * @profile: Profile number.
- * @mode:    Access control mode.
- * @bprm:    Pointer to "struct linux_binprm". May be NULL.
+ * @len: Required size.
+ * @r:   Pointer to "struct ccs_request_info".
  *
  * Returns pointer to allocated memory.
  *
  * The @len is updated to add the header lines' size on success.
  */
-char *ccs_init_audit_log(int *len, const u8 profile, const u8 mode,
-			 struct linux_binprm *bprm)
+char *ccs_init_audit_log(int *len, struct ccs_request_info *r)
 {
-	static const char *mode_4[4] = {
+	static const char *ccs_mode_4[4] = {
 		"disabled", "learning", "permissive", "enforcing"
 	};
 	char *buf;
 	char *bprm_info = "";
+	const char *symlink_head = "";
+	const char *symlink_tail = "";
+	const char *symlink_info = "";
 	struct timeval tv;
-	struct task_struct *task = current;
-	u32 tomoyo_flags = task->tomoyo_flags;
-	const char *domainname = current->domain_info->domainname->name;
+	u32 ccs_flags = current->ccs_flags;
+	const char *domainname;
+	if (!r->domain)
+		r->domain = ccs_current_domain();
+	domainname = r->domain->domainname->name;
 	do_gettimeofday(&tv);
 	*len += strlen(domainname) + 256;
-	if (bprm) {
-		bprm_info = ccs_print_bprm(bprm);
+	if (r->ee) {
+		bprm_info = ccs_print_bprm(r->ee->bprm, &r->ee->dump);
 		if (!bprm_info)
 			return NULL;
 		*len += strlen(bprm_info);
 	}
-	buf = ccs_alloc(*len);
+	if (r->obj && r->obj->symlink_target) {
+		symlink_head = "symlink.target=\"";
+		symlink_info = r->obj->symlink_target->name;
+		symlink_tail = "\" ";
+		*len += 18 + strlen(symlink_info);
+	}
+	buf = ccs_alloc(*len, true);
 	if (buf)
 		snprintf(buf, (*len) - 1,
 			 "#timestamp=%lu profile=%u mode=%s pid=%d uid=%d "
 			 "gid=%d euid=%d egid=%d suid=%d sgid=%d fsuid=%d "
-			 "fsgid=%d state[0]=%u state[1]=%u state[2]=%u %s\n"
-			 "%s\n", tv.tv_sec, profile, mode_4[mode], task->pid,
-			 task->uid, task->gid, task->euid, task->egid,
-			 task->suid, task->sgid, task->fsuid, task->fsgid,
-			 (u8) (tomoyo_flags >> 24), (u8) (tomoyo_flags >> 16),
-			 (u8) (tomoyo_flags >> 8), bprm_info, domainname);
-	if (bprm)
+			 "fsgid=%d state[0]=%u state[1]=%u state[2]=%u "
+			 "%s%s%s%s\n%s\n",
+			 tv.tv_sec, r->profile, ccs_mode_4[r->mode],
+			 (pid_t) sys_getpid(), current_uid(), current_gid(),
+			 current_euid(), current_egid(), current_suid(),
+			 current_sgid(), current_fsuid(), current_fsgid(),
+			 (u8) (ccs_flags >> 24), (u8) (ccs_flags >> 16),
+			 (u8) (ccs_flags >> 8), symlink_head, symlink_info,
+			 symlink_tail, bprm_info, domainname);
+	if (r->ee)
 		ccs_free(bprm_info);
 	return buf;
 }
 
 /**
- * get_max_grant_log - Get max number of spoolable grant logs.
+ * ccs_update_task_state - Update task's state.
  *
- * Returns max number of spoolable grant logs.
+ * @r:          Pointer to "struct ccs_request_info".
  */
-static unsigned int get_max_grant_log(void)
+static void ccs_update_task_state(struct ccs_request_info *r)
 {
-	return ccs_check_flags(CCS_TOMOYO_MAX_GRANT_LOG);
+	/*
+	 * Don't change the lowest byte because it is reserved for
+	 * CCS_CHECK_READ_FOR_OPEN_EXEC / CCS_DONT_SLEEP_ON_ENFORCE_ERROR /
+	 * CCS_TASK_IS_EXECUTE_HANDLER / CCS_TASK_IS_POLICY_MANAGER.
+	 */
+	const struct ccs_condition_list *ptr = r->cond;
+	if (ptr) {
+		struct task_struct *task = current;
+		const u8 flags = ptr->post_state[3];
+		u32 ccs_flags = task->ccs_flags;
+		if (flags & 1) {
+			ccs_flags &= ~0xFF000000;
+			ccs_flags |= ptr->post_state[0] << 24;
+		}
+		if (flags & 2) {
+			ccs_flags &= ~0x00FF0000;
+			ccs_flags |= ptr->post_state[1] << 16;
+		}
+		if (flags & 4) {
+			ccs_flags &= ~0x0000FF00;
+			ccs_flags |= ptr->post_state[2] << 8;
+		}
+		task->ccs_flags = ccs_flags;
+		r->cond = NULL;
+	}
 }
 
+#ifndef CONFIG_TOMOYO_AUDIT
+
 /**
- * get_max_reject_log - Get max number of spoolable reject logs.
+ * ccs_write_audit_log - Write audit log.
  *
- * Returns max number of spoolable reject logs.
+ * @is_granted: True if this is a granted log.
+ * @r:          Pointer to "struct ccs_request_info".
+ * @fmt:        The printf()'s format string, followed by parameters.
+ *
+ * Returns 0 on success, -ENOMEM otherwise.
  */
-static unsigned int get_max_reject_log(void)
+int ccs_write_audit_log(const bool is_granted, struct ccs_request_info *r,
+			const char *fmt, ...)
 {
-	return ccs_check_flags(CCS_TOMOYO_MAX_REJECT_LOG);
+	ccs_update_task_state(r);
+	return 0;
+}
+
+#else
+
+static DECLARE_WAIT_QUEUE_HEAD(ccs_grant_log_wait);
+static DECLARE_WAIT_QUEUE_HEAD(ccs_reject_log_wait);
+
+static DEFINE_SPINLOCK(ccs_audit_log_lock);
+
+/* Structure for audit log. */
+struct ccs_log_entry {
+	struct list_head list;
+	char *log;
+};
+
+/* The list for "struct ccs_log_entry". */
+static LIST_HEAD(ccs_grant_log);
+
+/* The list for "struct ccs_log_entry". */
+static LIST_HEAD(ccs_reject_log);
+
+static int ccs_grant_log_count;
+static int ccs_reject_log_count;
+
+/**
+ * ccs_can_save_audit_log - Check whether the kernel can save new audit log.
+ *
+ * @domain:     Pointer to "struct ccs_domain_info".
+ *              NULL for ccs_current_domain().
+ * @is_granted: True if this is a granted log.
+ *
+ * Returns true if the kernel can save, false otherwise.
+ */
+static bool ccs_can_save_audit_log(const struct ccs_domain_info *domain,
+				   const bool is_granted)
+{
+	if (is_granted)
+		return ccs_grant_log_count
+			< ccs_check_flags(domain, CCS_MAX_GRANT_LOG);
+	return ccs_reject_log_count
+		< ccs_check_flags(domain, CCS_MAX_REJECT_LOG);
 }
 
 /**
  * ccs_write_audit_log - Write audit log.
  *
- * @buf:        Pointer to audit log.
  * @is_granted: True if this is a granted log.
+ * @r:          Pointer to "struct ccs_request_info".
+ * @fmt:        The printf()'s format string, followed by parameters.
  *
  * Returns 0 on success, -ENOMEM otherwise.
- *
- * Caller must allocate @buf with ccs_init_audit_log().
  */
-int ccs_write_audit_log(char *buf, const bool is_granted)
+int ccs_write_audit_log(const bool is_granted, struct ccs_request_info *r,
+			const char *fmt, ...)
 {
-	struct log_entry *new_entry = ccs_alloc(sizeof(*new_entry));
-	if (!new_entry)
+	va_list args;
+	int error = -ENOMEM;
+	int pos;
+	int len;
+	char *buf;
+	struct ccs_log_entry *new_entry;
+	if (!r->domain)
+		r->domain = ccs_current_domain();
+	if (!ccs_can_save_audit_log(r->domain, is_granted))
 		goto out;
-	INIT_LIST_HEAD(&new_entry->list);
+	va_start(args, fmt);
+	len = vsnprintf((char *) &pos, sizeof(pos) - 1, fmt, args) + 32;
+	va_end(args);
+	buf = ccs_init_audit_log(&len, r);
+	if (!buf)
+		goto out;
+	pos = strlen(buf);
+	va_start(args, fmt);
+	vsnprintf(buf + pos, len - pos - 1, fmt, args);
+	va_end(args);
+	new_entry = ccs_alloc(sizeof(*new_entry), true);
+	if (!new_entry) {
+		ccs_free(buf);
+		goto out;
+	}
 	new_entry->log = buf;
 	/***** CRITICAL SECTION START *****/
-	spin_lock(&audit_log_lock);
+	spin_lock(&ccs_audit_log_lock);
 	if (is_granted) {
-		if (grant_log_count < get_max_grant_log()) {
-			list_add_tail(&new_entry->list, &grant_log);
-			grant_log_count++;
-			buf = NULL;
-			ccs_update_counter(CCS_UPDATES_COUNTER_GRANT_LOG);
-		}
+		list_add_tail(&new_entry->list, &ccs_grant_log);
+		ccs_grant_log_count++;
+		ccs_update_counter(CCS_UPDATES_COUNTER_GRANT_LOG);
 	} else {
-		if (reject_log_count < get_max_reject_log()) {
-			list_add_tail(&new_entry->list, &reject_log);
-			reject_log_count++;
-			buf = NULL;
-			ccs_update_counter(CCS_UPDATES_COUNTER_REJECT_LOG);
-		}
+		list_add_tail(&new_entry->list, &ccs_reject_log);
+		ccs_reject_log_count++;
+		ccs_update_counter(CCS_UPDATES_COUNTER_REJECT_LOG);
 	}
-	spin_unlock(&audit_log_lock);
+	spin_unlock(&ccs_audit_log_lock);
 	/***** CRITICAL SECTION END *****/
 	if (is_granted)
-		wake_up(&grant_log_wait);
+		wake_up(&ccs_grant_log_wait);
 	else
-		wake_up(&reject_log_wait);
-	if (!buf)
-		return 0;
-	ccs_free(new_entry);
+		wake_up(&ccs_reject_log_wait);
+	error = 0;
  out:
-	ccs_free(buf);
-	return -ENOMEM;
-}
-
-/**
- * ccs_can_save_audit_log - Check whether the kernel can save new audit log.
- *
- * @is_granted: True if this is a granted log.
- *
- * Returns 0 if the kernel can save, -ENOMEM otherwise.
- */
-int ccs_can_save_audit_log(const bool is_granted)
-{
-	if (is_granted) {
-		if (grant_log_count < get_max_grant_log())
-			return 0;
-	} else {
-		if (reject_log_count < get_max_reject_log())
-			return 0;
-	}
-	return -ENOMEM;
+	ccs_update_task_state(r);
+	return error;
 }
 
 /**
@@ -298,7 +336,7 @@ int ccs_can_save_audit_log(const bool is_granted)
  */
 int ccs_read_grant_log(struct ccs_io_buffer *head)
 {
-	struct log_entry *ptr = NULL;
+	struct ccs_log_entry *ptr = NULL;
 	if (head->read_avail)
 		return 0;
 	if (head->read_buf) {
@@ -307,13 +345,14 @@ int ccs_read_grant_log(struct ccs_io_buffer *head)
 		head->readbuf_size = 0;
 	}
 	/***** CRITICAL SECTION START *****/
-	spin_lock(&audit_log_lock);
-	if (!list_empty(&grant_log)) {
-		ptr = list_entry(grant_log.next, struct log_entry, list);
+	spin_lock(&ccs_audit_log_lock);
+	if (!list_empty(&ccs_grant_log)) {
+		ptr = list_entry(ccs_grant_log.next, struct ccs_log_entry,
+				 list);
 		list_del(&ptr->list);
-		grant_log_count--;
+		ccs_grant_log_count--;
 	}
-	spin_unlock(&audit_log_lock);
+	spin_unlock(&ccs_audit_log_lock);
 	/***** CRITICAL SECTION END *****/
 	if (ptr) {
 		head->read_buf = ptr->log;
@@ -334,10 +373,10 @@ int ccs_read_grant_log(struct ccs_io_buffer *head)
  */
 int ccs_poll_grant_log(struct file *file, poll_table *wait)
 {
-	if (grant_log_count)
+	if (ccs_grant_log_count)
 		return POLLIN | POLLRDNORM;
-	poll_wait(file, &grant_log_wait, wait);
-	if (grant_log_count)
+	poll_wait(file, &ccs_grant_log_wait, wait);
+	if (ccs_grant_log_count)
 		return POLLIN | POLLRDNORM;
 	return 0;
 }
@@ -351,7 +390,7 @@ int ccs_poll_grant_log(struct file *file, poll_table *wait)
  */
 int ccs_read_reject_log(struct ccs_io_buffer *head)
 {
-	struct log_entry *ptr = NULL;
+	struct ccs_log_entry *ptr = NULL;
 	if (head->read_avail)
 		return 0;
 	if (head->read_buf) {
@@ -360,13 +399,14 @@ int ccs_read_reject_log(struct ccs_io_buffer *head)
 		head->readbuf_size = 0;
 	}
 	/***** CRITICAL SECTION START *****/
-	spin_lock(&audit_log_lock);
-	if (!list_empty(&reject_log)) {
-		ptr = list_entry(reject_log.next, struct log_entry, list);
+	spin_lock(&ccs_audit_log_lock);
+	if (!list_empty(&ccs_reject_log)) {
+		ptr = list_entry(ccs_reject_log.next, struct ccs_log_entry,
+				 list);
 		list_del(&ptr->list);
-		reject_log_count--;
+		ccs_reject_log_count--;
 	}
-	spin_unlock(&audit_log_lock);
+	spin_unlock(&ccs_audit_log_lock);
 	/***** CRITICAL SECTION END *****/
 	if (ptr) {
 		head->read_buf = ptr->log;
@@ -387,10 +427,11 @@ int ccs_read_reject_log(struct ccs_io_buffer *head)
  */
 int ccs_poll_reject_log(struct file *file, poll_table *wait)
 {
-	if (reject_log_count)
+	if (ccs_reject_log_count)
 		return POLLIN | POLLRDNORM;
-	poll_wait(file, &reject_log_wait, wait);
-	if (reject_log_count)
+	poll_wait(file, &ccs_reject_log_wait, wait);
+	if (ccs_reject_log_count)
 		return POLLIN | POLLRDNORM;
 	return 0;
 }
+#endif
